'use strict';Object.defineProperty(exports, '__esModule', { value: true });var _createClass = (function () {function defineProperties(target, props) {for (var i = 0; i < props.length; i++) {var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ('value' in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);}}return function (Constructor, protoProps, staticProps) {if (protoProps) defineProperties(Constructor.prototype, protoProps);if (staticProps) defineProperties(Constructor, staticProps);return Constructor;};})();function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { 'default': obj };}function _classCallCheck(instance, Constructor) {if (!(instance instanceof Constructor)) {throw new TypeError('Cannot call a class as a function');}}var _FormSegmentJs = require('./FormSegment.js');var _FormSegmentJs2 = _interopRequireDefault(_FormSegmentJs);var _PromiseUtilJs = require(
'../PromiseUtil.js');var _PromiseUtilJs2 = _interopRequireDefault(_PromiseUtilJs);var _helperJs = require(
'../helper.js');

/**
 * Represents a form. Instance of this class may be passed to each Field
 * component. It can later be used to orchestrate various actions between
 * fields.
 *
 * @CLIENT_SERVER
 */var 
Form = (function () {

























  /**
   * @param {ReduxStore} reduxStore
   * @param {string} formId
   */
  function Form(reduxStore, formId) {_classCallCheck(this, Form);
    this._actionCreator = reduxStore.register(_FormSegmentJs2['default']);
    this._formId = formId;
    this._reduxStore = reduxStore;
    this._fields = {};
    this._fieldNames = [];}


  /**
   * @returns {string}
   */_createClass(Form, [{ key: 'getFormId', value: 
    function getFormId() {
      return this._formId;}


    /**
     * Disables the form by setting isEnabled to false.
     */ }, { key: 'disable', value: 
    function disable() {
      this._reduxStore.dispatch(this._actionCreator.setFormEnabledState(
      this._formId, false));}



    /**
     * Enables the form by setting isEnabled to true.
     */ }, { key: 'enable', value: 
    function enable() {
      this._reduxStore.dispatch(this._actionCreator.setFormEnabledState(
      this._formId, true));} }, { key: 'disableField', value: 



    function disableField(fieldName) {
      this.disableFields([fieldName]);} }, { key: 'enableField', value: 


    function enableField(fieldName) {
      this.enableFields([fieldName]);} }, { key: 'disableFields', value: 


    function disableFields(fieldNameList) {
      var i, data = [];
      for (i = 0; i < fieldNameList.length; i++) {
        data.push({ 
          fieldName: fieldNameList[i], 
          object: { isEnabled: false } });}


      this._reduxStore.dispatch(this._actionCreator.mergeFields(
      this._formId, data));} }, { key: 'enableFields', value: 



    function enableFields(fieldNameList) {
      var i, data = [];
      for (i = 0; i < fieldNameList.length; i++) {
        data.push({ 
          fieldName: fieldNameList[i], 
          object: { isEnabled: true } });}


      this._reduxStore.dispatch(this._actionCreator.mergeFields(
      this._formId, data));} }, { key: 'setValue', value: 



    function setValue(fieldName, value) {
      this._reduxStore.dispatch(this._actionCreator.setValue(
      this._formId, fieldName, value));} }, { key: 'setValues', value: 



    function setValues(values) {
      this._reduxStore.dispatch(this._actionCreator.setValues(
      this._formId, values));} }, { key: 'setDefaultValue', value: 



    function setDefaultValue(fieldName, value) {
      this._reduxStore.dispatch(this._actionCreator.setDefaultValue(
      this._formId, fieldName, value));} }, { key: 'setDefaultValues', value: 



    function setDefaultValues(values) {
      this._reduxStore.dispatch(this._actionCreator.setDefaultValues(
      this._formId, values));} }, { key: 'setErrors', value: 



    function setErrors(fieldName, errorMessages) {
      this._reduxStore.dispatch(this._actionCreator.setErrorMessages(
      this._formId, fieldName, errorMessages));} }, { key: 'addErrors', value: 



    function addErrors(errorMessages) {
      this._reduxStore.dispatch(this._actionCreator.addErrorMessages(
      this._formId, errorMessages));} }, { key: 'clearForm', value: 



    function clearForm() {
      this._reduxStore.dispatch(this._actionCreator.clear(
      this._formId));} }, { key: 'clearErrors', value: 



    function clearErrors(fieldNames) {
      this._reduxStore.dispatch(this._actionCreator.clearErrorMessages(
      this._formId, fieldNames));}



    /**
     * @param {Array<string>|string} fieldName
     * @param {Function} validateAll
     */ }, { key: 'regField', value: 
    function regField(fieldName, validateAll) {
      this._fieldNames.push(fieldName);
      this._fields[fieldName.toString()] = { validateAll: validateAll };}


    /**
     * @param {Array<string>|string} fieldName
     */ }, { key: 'unregField', value: 
    function unregField(fieldName) {
      // Since fieldName could be an Array, we'd have to loop manually to remove.
      var i, found = false, fieldNameInLoop;
      for (i = 0; i < this._fieldNames.length; i++) {
        fieldNameInLoop = this._fieldNames[i];
        if ((0, _helperJs.isStringDuckType)(fieldNameInLoop) && 
        (0, _helperJs.isStringDuckType)(fieldName) && fieldNameInLoop == fieldName) {
          found = true;
          break;} else 
        if ((0, _helperJs.isArrayDuckType)(fieldNameInLoop) && (0, _helperJs.isArrayDuckType)(fieldName) && 
        (0, _helperJs.isEqualShallowArray)(fieldNameInLoop, fieldName)) {
          found = true;
          break;}}


      if (found) {
        this._fieldNames.splice(i, 1);}

      delete this._fields[fieldName.toString()];}


    /**
     * Returns a promise that resolves to the following object:
     *
     * <pre>
     *   {
     *     isValid: true/false,
     *     values: {
     *       fieldName: (value),
     *       ...
     *     }
     *   }
     * </pre>
     *
     * @return {Promise}
     */ }, { key: 'validateAll', value: 
    function validateAll() {
      var fieldName, promises = [];
      for (fieldName in this._fields) {
        if (!this._fields.hasOwnProperty(fieldName)) continue;
        promises.push(this._fields[fieldName].validateAll());}

      var finalPromise = _PromiseUtilJs2['default'].allParallel(Promise, promises);
      return finalPromise.then(
      function (validationResults) {
        var i, j, result, values = {}, isValid = true;
        for (i = 0; i < validationResults.length; i++) {
          result = validationResults[i];
          isValid = isValid && result.isValid;
          if ((0, _helperJs.isStringDuckType)(result.name)) {
            values[result.name] = result.value;
            continue;}

          var ref = values, namePiece, finalPieceIdx = result.name.length - 1;
          for (j = 0; j < result.name.length; j++) {
            namePiece = result.name[j];
            if (j == finalPieceIdx) {
              ref[namePiece] = result.value;} else 
            if (ref.hasOwnProperty(namePiece)) {
              // no-op.
            } else if (result.name[j + 1].substring) {
                ref[namePiece] = {};} else 
              {
                ref[namePiece] = [];}

            ref = ref[namePiece];}}


        return { values: values, isValid: isValid };})['catch'](

      _PromiseUtilJs2['default'].throwError);} }, { key: 'submit', value: 


    function submit(submitFunc, validationFunc) {var _this = this;
      this.disable();

      // We need to clear all error messages, since form-wide validation doesn't
      // return with arrays to clear all error messages.
      var clearErrorMessages = this._actionCreator.clearErrorMessages(
      this._formId, this._fieldNames);
      var promise = this._reduxStore.dispatch(clearErrorMessages);

      promise.then(function () {
        var validateAllPromise = _this.validateAll();
        validateAllPromise.then(function (result) {
          if (!result.isValid || validationFunc == null) {
            submitFunc(result);
            _this.enable();
            return;}

          // Result is valid and validation function is not null. Do form-wide validation.
          var formWideValidationPromise = Promise.resolve(validationFunc(result.values));
          formWideValidationPromise.then(function (formWideValidationResult) {
            if (typeof formWideValidationResult == 'object' && !formWideValidationResult.isValid) {
              // Render error messages.
              _this._reduxStore.dispatch(_this._actionCreator.addErrorMessages(
              _this._formId, formWideValidationResult.errorMessages));

              result.isValid = false;}

            submitFunc(result);
            _this.enable();})['catch'](
          function (error) {
            result.isValid = false;
            submitFunc(result);
            _this.enable();
            _PromiseUtilJs2['default'].throwError(error);});})['catch'](

        function (error) {
          _this.enable();
          _PromiseUtilJs2['default'].throwError(error);});})['catch'](

      function (error) {
        _this.enable();
        _PromiseUtilJs2['default'].throwError(error);});} }]);return Form;})();exports['default'] = Form;module.exports = exports['default']; /**
                                                                                                                                               * @type {ReduxStore}
                                                                                                                                               */ /**
                                                                                                                                                   * @type {string}
                                                                                                                                                   */ /**
                                                                                                                                                       * @type {Object}
                                                                                                                                                       */ /**
                                                                                                                                                           * @type {Array<string | Array<string>>}
                                                                                                                                                           */ /**
                                                                                                                                                               * @type {Object<Function>}
                                                                                                                                                               */
//# sourceMappingURL=Form.js.map